##  Introduction
Once the SAP Cloud ALM integration is successfully set up, you can selectively import, export, and synchronize projects between the 2 systems with the following options:
  * Sync a project from SAP Cloud ALM to an existing initiative fact sheet.
  * Import a project from SAP Cloud ALM as a new initiative fact sheet, either as a child fact sheet or as a new standalone fact sheet.
  * Export a project to SAP Cloud ALM from SAP LeanIX’s initiative and project fact sheets.


To do so, follow these steps:
  1. Navigate to the initiative fact sheet or its subtypes (project and transformation) that you want to link.
  2. In the fact sheet, select the Agile Tracking tab.
  3. Click Set Up Sync.
  4. The resulting overlay gives you options for importing, exporting, and syncing projects. Based on your needs, choose the relevant option and complete the process.


![Syncing Initiatives and Projects in the Agile Tracking Tab of the Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757867e7a441014a81ed13a01bd3781_LowRes.png)
Syncing Initiatives and Projects in the Agile Tracking Tab of the Fact Sheet
